#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: views.py 12419 2020-07-23 07:57:14Z Casey $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Casey $
# $Date: 2020-07-23 16:57:14 +0900 (週四, 23 七月 2020) $
# $Revision: 12419 $

import json
import six
import urllib

import django
from django.views.generic import View, FormView
from django.contrib import messages
from django.conf import settings
from django.core.mail import send_mail
from django.http import HttpResponse
from django.utils.translation import ugettext_lazy as _
from django.views.decorators.csrf import csrf_exempt
from django.utils.decorators import method_decorator
from django.contrib.auth.decorators import permission_required
from django.shortcuts import redirect, get_object_or_404
from django.contrib.auth import get_user_model

from Iuppiter.Encoding import utf8
from Zephyrus.comment.models import Comment, CommentPlugin
from Zephyrus.comment.forms import CommentForm

DJANGO_VERSION = (django.VERSION[0] * 10000 + django.VERSION[1] * 100 +
                  django.VERSION[2])

class CommentView(FormView): 

    form_class = CommentForm

    def form_valid(self, form):
        # create comment
        url = self.request.POST.get('url')
        message = self.request.POST.get('message')
        
        if DJANGO_VERSION < 20000: # 2.0.0
            if self.request.user.is_anonymous():
                email = self.request.POST.get('email')
                comment = Comment(
                    url=url,
                    user=None,
                    email=email,
                    message=message,
                )
                username = email
            else:
                user = self.request.user
                comment = Comment(
                    url=url,
                    user=user,
                    email=None,
                    message=message,
                )
                username = user.username
        else: 
            if self.request.user.is_anonymous:
                email = self.request.POST.get('email')
                comment = Comment(
                    url=url,
                    user=None,
                    email=email,
                    message=message,
                )
                username = email
            else:
                user = self.request.user
                comment = Comment(
                    url=url,
                    user=user,
                    email=None,
                    message=message,
                )
                username = user.username
        comment.save()
        
        # sand mail
        plugin = CommentPlugin.objects.get(id=self.request.POST.get('pluginId'))
        
        title =  _(
            '[Zephyrus comment %(host)s] somebody leave a comment.'
            ) % {
                'host': self.request.META['HTTP_HOST'],
            }
        message = _(
            "URL: %(url)s\nUsername: %(username)s\nMessage:"
            "\n%(message)s\nPost data:\n%(post)s"
            ) % {
                "url": url, 
                "username": username, 
                "message": message, 
                "post": self.request.POST
            }
        
        
        if plugin.emailTo:
            emailTo = plugin.emailTo.split(',')
        else:
            User = get_user_model()
            emailTo = [
                u.email for u in User.objects.filter(is_staff=True) if u.email
            ]
        
        send_mail(
            title,
            message,
            settings.EMAIL_HOST_USER,
            emailTo,
            fail_silently=False
        )
            
        return redirect(url)
        
    def form_invalid(self, form):
        url = self.request.POST.get('url')
        
        if form.errors:
            for e in form.errors:
                messages.error(self.request, form.errors[e])
                
        return redirect(url)
        
class CommentHideView(View): 

    @method_decorator(
        permission_required('comment.delete_comment', raise_exception=True))
    def dispatch(self, request, *args, **kwargs):
        return super(CommentHideView, self).dispatch(request, *args, **kwargs)
        
    def post(self, request, *args, **kwargs):
        pk = kwargs["pk"]
        
        comment = get_object_or_404(Comment, id=pk)
        
        if request.user.is_staff:
            comment.display = False
            comment.save()
        return redirect(comment.url)
        